Command Line Interface
======================
geometric_graphs automatically installs the command :code:`geometric_graphs`. See
:code:`geometric_graphs --help` for usage details.

.. click:: geometric_graphs.cli:main
   :prog: geometric_graphs
   :show-nested:
